@@ -5,7 +5,7 @@ use vars qw(@ISA $VERSION);
 
 require LWP::MemberMixin;
 @ISA = qw(LWP::MemberMixin);
-$VERSION = "6.00";
+$VERSION = "6.15_004";
 
 use HTTP::Request ();
 use HTTP::Response ();
@@ -16,22 +16,12 @@ use LWP::Protocol ();
 
 use Carp ();
 
-if ($ENV{PERL_LWP_USE_HTTP_10}) {
-    require LWP::Protocol::http10;
-    LWP::Protocol::implementor('http', 'LWP::Protocol::http10');
-    eval {
-        require LWP::Protocol::https10;
-        LWP::Protocol::implementor('https', 'LWP::Protocol::https10');
-    };
-}
-
-
 
 sub new
 {
     # Check for common user mistake
-    Carp::croak("Options to LWP::UserAgent should be key/value pairs, not hash reference") 
-        if ref($_[1]) eq 'HASH'; 
+    Carp::croak("Options to LWP::UserAgent should be key/value pairs, not hash reference")
+        if ref($_[1]) eq 'HASH';
 
     my($class, %cnf) = @_;
 
@@ -41,24 +31,27 @@ sub new
     my $timeout = delete $cnf{timeout};
     $timeout = 3*60 unless defined $timeout;
     my $local_address = delete $cnf{local_address};
-    my $ssl_opts = delete $cnf{ssl_opts};
-    unless ($ssl_opts) {
-	# The processing of HTTPS_CA_* below is for compatiblity with Crypt::SSLeay
-	$ssl_opts = {};
+    my $ssl_opts = delete $cnf{ssl_opts} || {};
+    unless (exists $ssl_opts->{verify_hostname}) {
+	# The processing of HTTPS_CA_* below is for compatibility with Crypt::SSLeay
 	if (exists $ENV{PERL_LWP_SSL_VERIFY_HOSTNAME}) {
 	    $ssl_opts->{verify_hostname} = $ENV{PERL_LWP_SSL_VERIFY_HOSTNAME};
 	}
 	elsif ($ENV{HTTPS_CA_FILE} || $ENV{HTTPS_CA_DIR}) {
-	    # Crypt-SSLeay compatiblity (verify peer certificate; but not the hostname)
+	    # Crypt-SSLeay compatibility (verify peer certificate; but not the hostname)
 	    $ssl_opts->{verify_hostname} = 0;
 	    $ssl_opts->{SSL_verify_mode} = 1;
 	}
 	else {
 	    $ssl_opts->{verify_hostname} = 1;
 	}
+    }
+    unless (exists $ssl_opts->{SSL_ca_file}) {
 	if (my $ca_file = $ENV{PERL_LWP_SSL_CA_FILE} || $ENV{HTTPS_CA_FILE}) {
 	    $ssl_opts->{SSL_ca_file} = $ca_file;
 	}
+    }
+    unless (exists $ssl_opts->{SSL_ca_path}) {
 	if (my $ca_path = $ENV{PERL_LWP_SSL_CA_PATH} || $ENV{HTTPS_CA_DIR}) {
 	    $ssl_opts->{SSL_ca_path} = $ca_path;
 	}
@@ -71,18 +64,18 @@ sub new
     my $max_size = delete $cnf{max_size};
     my $max_redirect = delete $cnf{max_redirect};
     $max_redirect = 7 unless defined $max_redirect;
-    my $env_proxy = delete $cnf{env_proxy};
+    my $env_proxy = exists $cnf{env_proxy} ? delete $cnf{env_proxy} : $ENV{PERL_LWP_ENV_PROXY};
 
     my $cookie_jar = delete $cnf{cookie_jar};
     my $conn_cache = delete $cnf{conn_cache};
     my $keep_alive = delete $cnf{keep_alive};
-    
+
     Carp::croak("Can't mix conn_cache and keep_alive")
 	  if $conn_cache && $keep_alive;
 
     my $protocols_allowed   = delete $cnf{protocols_allowed};
     my $protocols_forbidden = delete $cnf{protocols_forbidden};
-    
+
     my $requests_redirectable = delete $cnf{requests_redirectable};
     $requests_redirectable = ['GET', 'HEAD']
       unless defined $requests_redirectable;
@@ -183,12 +176,11 @@ sub send_request
                 $@ =~ s/ at .* line \d+.*//s;  # remove file/line number
                 $response =  _new_response($request, &HTTP::Status::RC_NOT_IMPLEMENTED, $@);
                 if ($scheme eq "https") {
-                    $response->message($response->message . " (IO::Socket::SSL not installed)");
+                    $response->message($response->message . " (LWP::Protocol::https not installed)");
                     $response->content_type("text/plain");
                     $response->content(<<EOT);
-LWP will support https URLs if either IO::Socket::SSL or Crypt::SSLeay
-is installed. More information at
-<http://search.cpan.org/dist/libwww-perl/README.SSL>.
+LWP will support https URLs if the LWP::Protocol::https module
+is installed.
 EOT
                 }
             }
@@ -311,7 +303,7 @@ sub request
 
 	# These headers should never be forwarded
 	$referral->remove_header('Host', 'Cookie');
-	
+
 	if ($referral->header('Referer') &&
 	    $request->uri->scheme eq 'https' &&
 	    $referral->uri->scheme eq 'http')
@@ -322,7 +314,7 @@ sub request
 	}
 
 	if ($code == &HTTP::Status::RC_SEE_OTHER ||
-	    $code == &HTTP::Status::RC_FOUND) 
+	    $code == &HTTP::Status::RC_FOUND)
         {
 	    my $method = uc($referral->method);
 	    unless ($method eq "GET" || $method eq "HEAD") {
@@ -354,10 +346,11 @@ sub request
 	    )
     {
 	my $proxy = ($code == &HTTP::Status::RC_PROXY_AUTHENTICATION_REQUIRED);
-	my $ch_header = $proxy ?  "Proxy-Authenticate" : "WWW-Authenticate";
+	my $ch_header = $proxy || $request->method eq 'CONNECT'
+	    ?  "Proxy-Authenticate" : "WWW-Authenticate";
 	my @challenge = $response->header($ch_header);
 	unless (@challenge) {
-	    $response->header("Client-Warning" => 
+	    $response->header("Client-Warning" =>
 			      "Missing Authenticate header");
 	    return $response;
 	}
@@ -371,7 +364,7 @@ sub request
 	    $challenge = { @$challenge };  # make rest into a hash
 
 	    unless ($scheme =~ /^([a-z]+(?:-[a-z]+)*)$/) {
-		$response->header("Client-Warning" => 
+		$response->header("Client-Warning" =>
 				  "Bad authentication scheme '$scheme'");
 		return $response;
 	    }
@@ -435,6 +428,22 @@ sub head {
 }
 
 
+sub put {
+    require HTTP::Request::Common;
+    my($self, @parameters) = @_;
+    my @suff = $self->_process_colonic_headers(\@parameters, (ref($parameters[1]) ? 2 : 1));
+    return $self->request( HTTP::Request::Common::PUT( @parameters ), @suff );
+}
+
+
+sub delete {
+    require HTTP::Request::Common;
+    my($self, @parameters) = @_;
+    my @suff = $self->_process_colonic_headers(\@parameters,1);
+    return $self->request( HTTP::Request::Common::DELETE( @parameters ), @suff );
+}
+
+
 sub _process_colonic_headers {
     # Process :content_cb / :content_file / :read_size_hint headers.
     my($self, $args, $start_index) = @_;
@@ -451,7 +460,7 @@ sub _process_colonic_headers {
 	    Carp::croak("A :content_cb value can't be undef") unless defined $arg;
 	    Carp::croak("A :content_cb value must be a coderef")
 		unless ref $arg and UNIVERSAL::isa($arg, 'CODE');
-	    
+
 	}
 	elsif ($args->[$i] eq ':content_file') {
 	    $arg = $args->[$i + 1];
@@ -484,6 +493,15 @@ sub _process_colonic_headers {
     return $arg;
 }
 
+
+sub is_online {
+    my $self = shift;
+    return 1 if $self->get("http://www.msftncsi.com/ncsi.txt")->content eq "Microsoft NCSI";
+    return 1 if $self->get("http://www.apple.com")->content =~ m,<title>Apple</title>,;
+    return 0;
+}
+
+
 my @ANI = qw(- \ | /);
 
 sub progress {
@@ -570,13 +588,13 @@ sub redirect_ok
     my $method = $response->request->method;
     return 0 unless grep $_ eq $method,
       @{ $self->requests_redirectable || [] };
-    
+
     if ($new_request->uri->scheme eq 'file') {
       $response->header("Client-Warning" =>
 			"Can't redirect to a file:// URL!");
       return 0;
     }
-    
+
     # Otherwise it's apparently okay...
     return 1;
 }
@@ -835,7 +853,7 @@ sub run_handlers {
 }
 
 
-# depreciated
+# deprecated
 sub use_eval   { shift->_elem('use_eval',  @_); }
 sub use_alarm
 {
@@ -899,7 +917,7 @@ sub mirror
     }
 
     # Only fetching a fresh copy of the would be considered success.
-    # If the file was not modified, "304" would returned, which 
+    # If the file was not modified, "304" would returned, which
     # is considered by HTTP::Status to be a "redirect", /not/ "success"
     if ( $response->is_success ) {
         my @stat        = stat($tmpfile) or die "Could not stat tmpfile '$tmpfile': $!";
@@ -914,11 +932,11 @@ sub mirror
             unlink($tmpfile);
             die "Content-length mismatch: " . "expected $content_length bytes, got $file_length\n";
         }
-        # The file was the expected length. 
+        # The file was the expected length.
         else {
             # Replace the stale file with a fresh copy
             if ( -e $file ) {
-                # Some dosish systems fail to rename if the target exists
+                # Some DOSish systems fail to rename if the target exists
                 chmod 0777, $file;
                 unlink $file;
             }
@@ -931,7 +949,7 @@ sub mirror
             }
         }
     }
-    # The local copy is fresh enough, so just delete the temp file  
+    # The local copy is fresh enough, so just delete the temp file
     else {
 	unlink($tmpfile);
     }
@@ -1019,6 +1037,7 @@ sub no_proxy {
 
 sub _new_response {
     my($request, $code, $message, $content) = @_;
+    $message ||= HTTP::Status::status_message($code);
     my $response = HTTP::Response->new($code, $message);
     $response->request($request);
     $response->header("Client-Date" => HTTP::Date::time2str(time));
@@ -1040,13 +1059,13 @@ LWP::UserAgent - Web user agent class
 =head1 SYNOPSIS
 
  require LWP::UserAgent;
- 
+
  my $ua = LWP::UserAgent->new;
  $ua->timeout(10);
  $ua->env_proxy;
- 
+
  my $response = $ua->get('http://search.cpan.org/');
- 
+
  if ($response->is_success) {
      print $response->decoded_content;  # or whatever
  }
@@ -1066,8 +1085,8 @@ needs to be performed. This request is then passed to one of the
 request method the UserAgent, which dispatches it using the relevant
 protocol, and returns a C<HTTP::Response> object.  There are
 convenience methods for sending the most common request types: get(),
-head() and post().  When using these methods then the creation of the
-request object is hidden as shown in the synopsis above.
+head(), post(), put() and delete().  When using these methods then the
+creation of the request object is hidden as shown in the synopsis above.
 
 The basic approach of the library is to use HTTP style communication
 for all protocol schemes.  This means that you will construct
@@ -1105,13 +1124,13 @@ The following options correspond to attribute methods described below:
    requests_redirectable   ['GET', 'HEAD']
    timeout                 180
 
-The following additional options are also accepted: If the
-C<env_proxy> option is passed in with a TRUE value, then proxy
-settings are read from environment variables (see env_proxy() method
-below).  If the C<keep_alive> option is passed in, then a
-C<LWP::ConnCache> is set up (see conn_cache() method below).  The
-C<keep_alive> value is passed on as the C<total_capacity> for the
-connection cache.
+The following additional options are also accepted: If the C<env_proxy> option
+is passed in with a TRUE value, then proxy settings are read from environment
+variables (see env_proxy() method below).  If C<env_proxy> isn't provided the
+C<PERL_LWP_ENV_PROXY> environment variable controls if env_proxy() is called
+during initialization.  If the C<keep_alive> option is passed in, then a
+C<LWP::ConnCache> is set up (see conn_cache() method below).  The C<keep_alive>
+value is passed on as the C<total_capacity> for the connection cache.
 
 =item $ua->clone
 
@@ -1177,8 +1196,8 @@ method for the more general interface that allow any header to be defaulted.
 =item $ua->cookie_jar( $cookie_jar_obj )
 
 Get/set the cookie jar object to use.  The only requirement is that
-the cookie jar object must implement the extract_cookies($request) and
-add_cookie_header($response) methods.  These methods will then be
+the cookie jar object must implement the extract_cookies($response) and
+add_cookie_header($request) methods.  These methods will then be
 invoked by the user agent as requests are sent and responses are
 received.  Normally this will be a C<HTTP::Cookies> object or some
 subclass.
@@ -1327,7 +1346,7 @@ change to include 'POST', consider:
 =item $ua->show_progress( $boolean )
 
 Get/set a value indicating whether a progress bar should be displayed
-on on the terminal as requests are processed. The default is FALSE.
+on the terminal as requests are processed. The default is FALSE.
 
 =item $ua->timeout
 
@@ -1361,10 +1380,10 @@ The options that LWP relates to are:
 When TRUE LWP will for secure protocol schemes ensure it connects to servers
 that have a valid certificate matching the expected hostname.  If FALSE no
 checks are made and you can't be sure that you communicate with the expected peer.
-The no checks behaviour was the default for libwww-perl-5.837 and older.
+The no checks behaviour was the default for libwww-perl-5.837 and earlier releases.
 
 This option is initialized from the L<PERL_LWP_SSL_VERIFY_HOSTNAME> environment
-variable.  If the this envirionment variable isn't set; then C<verify_hostname>
+variable.  If this environment variable isn't set; then C<verify_hostname>
 defaults to 1.
 
 =item C<SSL_ca_file> => $path
@@ -1385,11 +1404,9 @@ variables C<PERL_LWP_SSL_CA_PATH> and C<HTTPS_CA_DIR> in order.
 Other options can be set and are processed directly by the SSL Socket implementation
 in use.  See L<IO::Socket::SSL> or L<Net::SSL> for details.
 
-If hostname verification is requested, and neither C<SSL_ca_file> nor
-C<SSL_ca_path> is set, then C<SSL_ca_file> is implied to be the one
-provided by L<Mozilla::CA>.  If the Mozilla::CA module isn't available
-SSL requests will fail.  Either install this module, set up an alternative
-SSL_ca_file or disable hostname verification.
+The libwww-perl core no longer bundles protocol plugins for SSL.  You will need
+to install L<LWP::Protocol::https> separately to enable support for processing
+https-URLs.
 
 =back
 
@@ -1464,7 +1481,7 @@ The possible values $phase and the corresponding callback signatures are:
 =item request_preprepare => sub { my($request, $ua, $h) = @_; ... }
 
 The handler is called before the C<request_prepare> and other standard
-initialization of of the request.  This can be used to set up headers
+initialization of the request.  This can be used to set up headers
 and attributes that the C<request_prepare> handler depends on.  Proxy
 initialization should take place here; but in general don't register
 handlers for this phase.
@@ -1478,13 +1495,13 @@ certain headers to specific requests.
 The method can assign a new request object to $_[0] to replace the
 request that is sent fully.
 
-The return value from the callback is ignored.  If an exceptions is
+The return value from the callback is ignored.  If an exception is
 raised it will abort the request and make the request method return a
 "400 Bad request" response.
 
 =item request_send => sub { my($request, $ua, $h) = @_; ... }
 
-This handler get a chance of handling requests before it's sent to the
+This handler gets a chance of handling requests before they're sent to the
 protocol handlers.  It should return an HTTP::Response object if it
 wishes to terminate the processing; otherwise it should return nothing.
 
@@ -1504,10 +1521,10 @@ was called with a $content_file or $content_cb argument; otherwise true.
 
 =item response_data => sub { my($response, $ua, $h, $data) = @_; ... }
 
-This handlers is called for each chunk of data received for the
+This handler is called for each chunk of data received for the
 response.  The handler might croak to abort the request.
 
-This handler need to return a TRUE value to be called again for
+This handler needs to return a TRUE value to be called again for
 subsequent chunks for the same request.
 
 =item response_done => sub { my($response, $ua, $h) = @_; ... }
@@ -1519,7 +1536,7 @@ extract information or modify the response.
 =item response_redirect => sub { my($response, $ua, $h) = @_; ... }
 
 The handler is called in $ua->request after C<response_done>.  If the
-handler return an HTTP::Request object we'll start over with processing
+handler returns an HTTP::Request object we'll start over with processing
 this request instead.
 
 =back
@@ -1531,7 +1548,7 @@ this request instead.
 Remove handlers that match the given %matchspec.  If $phase is not
 provided remove handlers from all phases.
 
-Be careful as calling this function with %matchspec that is not not
+Be careful as calling this function with %matchspec that is not
 specific enough can remove handlers not owned by you.  It's probably
 better to use the set_my_handler() method instead.
 
@@ -1551,7 +1568,7 @@ If $cb is passed as C<undef>, remove the handler.
 
 Will retrieve the matching handler as hash ref.
 
-If C<$init> is passed passed as a TRUE value, create and add the
+If C<$init> is passed as a TRUE value, create and add the
 handler if it's not found.  If $init is a subroutine reference, then
 it's called with the created handler hash as argument.  This sub might
 populate the hash with extra fields; especially the callback.  If
@@ -1651,6 +1668,38 @@ This method will use the POST() function from C<HTTP::Request::Common>
 to build the request.  See L<HTTP::Request::Common> for a details on
 how to pass form content and other advanced features.
 
+=item $ua->put( $url, \%form )
+
+=item $ua->put( $url, \@form )
+
+=item $ua->put( $url, \%form, $field_name => $value, ... )
+
+=item $ua->put( $url, $field_name => $value,... Content => \%form )
+
+=item $ua->put( $url, $field_name => $value,... Content => \@form )
+
+=item $ua->put( $url, $field_name => $value,... Content => $content )
+
+This method will dispatch a C<PUT> request on the given $url, with
+%form or @form providing the key/value pairs for the fill-in form
+content. Additional headers and content options are the same as for
+the get() method.
+
+This method will use the PUT() function from C<HTTP::Request::Common>
+to build the request.  See L<HTTP::Request::Common> for a details on
+how to pass form content and other advanced features.
+
+=item $ua->delete( $url )
+
+=item $ua->delete( $url, $field_name => $value, ... )
+
+This method will dispatch a C<DELETE> request on the given $url.  Additional
+headers and content options are the same as for the get() method.
+
+This method will use the DELETE() function from C<HTTP::Request::Common>
+to build the request.  See L<HTTP::Request::Common> for a details on
+how to pass form content and other advanced features.
+
 =item $ua->mirror( $url, $filename )
 
 This method will get the document identified by $url and store it in
@@ -1661,7 +1710,7 @@ this time, then nothing happens.  If the document has been updated, it
 will be downloaded again.  The modification time of the file will be
 forced to match that of the server.
 
-The return value is the the response object.
+The return value is the response object.
 
 =item $ua->request( $request )
 
@@ -1710,6 +1759,12 @@ The difference from request() is that simple_request() will not try to
 handle redirects or authentication responses.  The request() method
 will in fact invoke this method for each simple request it sends.
 
+=item $ua->is_online
+
+Tries to determine if you have access to the Internet.  Returns
+TRUE if the built-in heuristics determine that the user agent is
+able to access the Internet (over HTTP).  See also L<LWP::Online>.
+
 =item $ua->is_protocol_supported( $scheme )
 
 You can use this method to test whether this user agent object supports the
